# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/featuregroup/v1/featuregroup.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nIgithub.com/metaprov/modelaapi/services/featuregroup/v1/featuregroup.proto\x12\x36github.com.metaprov.modelaapi.services.featuregroup.v1\x1a google/protobuf/field_mask.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x44github.com/metaprov/modelaapi/pkg/apis/data/v1alpha1/generated.proto\"\x81\x02\n\x17ListFeatureGroupRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12k\n\x06labels\x18\x02 \x03(\x0b\x32[.github.com.metaprov.modelaapi.services.featuregroup.v1.ListFeatureGroupRequest.LabelsEntry\x12\x11\n\tpage_size\x18\x03 \x01(\x05\x12\x12\n\npage_token\x18\x04 \x01(\t\x12\x10\n\x08order_by\x18\x05 \x01(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x92\x01\n\x18ListFeatureGroupResponse\x12]\n\rfeaturegroups\x18\x01 \x01(\x0b\x32\x46.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FeatureGroupList\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"u\n\x19\x43reateFeatureGroupRequest\x12X\n\x0c\x66\x65\x61turegroup\x18\x01 \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FeatureGroup\"\x1c\n\x1a\x43reateFeatureGroupResponse\"\xa5\x01\n\x19UpdateFeatureGroupRequest\x12X\n\x0c\x66\x65\x61turegroup\x18\x01 \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FeatureGroup\x12.\n\nfield_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\"\x1c\n\x1aUpdateFeatureGroupResponse\"9\n\x16GetFeatureGroupRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x81\x01\n\x17GetFeatureGroupResponse\x12X\n\x0c\x66\x65\x61turegroup\x18\x01 \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FeatureGroup\x12\x0c\n\x04yaml\x18\x02 \x01(\t\"<\n\x19\x44\x65leteFeatureGroupRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x1c\n\x1a\x44\x65leteFeatureGroupResponse\"\x1b\n\x19PauseFeatureGroupResponse\";\n\x18PauseFeatureGroupRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x1c\n\x1aResumeFeatureGroupResponse\"<\n\x19ResumeFeatureGroupRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t2\x9c\r\n\x13\x46\x65\x61tureGroupService\x12\xdd\x01\n\x11ListFeatureGroups\x12O.github.com.metaprov.modelaapi.services.featuregroup.v1.ListFeatureGroupRequest\x1aP.github.com.metaprov.modelaapi.services.featuregroup.v1.ListFeatureGroupResponse\"%\x82\xd3\xe4\x93\x02\x1f\x12\x1d/v1/featuregroups/{namespace}\x12\xd9\x01\n\x12\x43reateFeatureGroup\x12Q.github.com.metaprov.modelaapi.services.featuregroup.v1.CreateFeatureGroupRequest\x1aR.github.com.metaprov.modelaapi.services.featuregroup.v1.CreateFeatureGroupResponse\"\x1c\x82\xd3\xe4\x93\x02\x16\"\x11/v1/featuregroups:\x01*\x12\xe0\x01\n\x0fGetFeatureGroup\x12N.github.com.metaprov.modelaapi.services.featuregroup.v1.GetFeatureGroupRequest\x1aO.github.com.metaprov.modelaapi.services.featuregroup.v1.GetFeatureGroupResponse\",\x82\xd3\xe4\x93\x02&\x12$/v1/featuregroups/{namespace}/{name}\x12\x98\x02\n\x12UpdateFeatureGroup\x12Q.github.com.metaprov.modelaapi.services.featuregroup.v1.UpdateFeatureGroupRequest\x1aR.github.com.metaprov.modelaapi.services.featuregroup.v1.UpdateFeatureGroupResponse\"[\x82\xd3\xe4\x93\x02U\x1aP/v1/featuregroups/{featuregroup.metadata.namespace}/{featuregroup.metadata.name}:\x01*\x12\xe9\x01\n\x12\x44\x65leteFeatureGroup\x12Q.github.com.metaprov.modelaapi.services.featuregroup.v1.DeleteFeatureGroupRequest\x1aR.github.com.metaprov.modelaapi.services.featuregroup.v1.DeleteFeatureGroupResponse\",\x82\xd3\xe4\x93\x02&*$/v1/featuregroups/{namespace}/{name}\x12\xec\x01\n\x11PauseFeatureGroup\x12P.github.com.metaprov.modelaapi.services.featuregroup.v1.PauseFeatureGroupRequest\x1aQ.github.com.metaprov.modelaapi.services.featuregroup.v1.PauseFeatureGroupResponse\"2\x82\xd3\xe4\x93\x02,\"*/v1/featuregroups/{namespace}/{name}:pause\x12\xef\x01\n\x12ResumeFeatureGroup\x12Q.github.com.metaprov.modelaapi.services.featuregroup.v1.ResumeFeatureGroupRequest\x1aR.github.com.metaprov.modelaapi.services.featuregroup.v1.ResumeFeatureGroupResponse\"2\x82\xd3\xe4\x93\x02,\"*/v1/featuregroups/{namespace}/{name}:pauseB8Z6github.com/metaprov/modelaapi/services/featuregroup/v1b\x06proto3')



_LISTFEATUREGROUPREQUEST = DESCRIPTOR.message_types_by_name['ListFeatureGroupRequest']
_LISTFEATUREGROUPREQUEST_LABELSENTRY = _LISTFEATUREGROUPREQUEST.nested_types_by_name['LabelsEntry']
_LISTFEATUREGROUPRESPONSE = DESCRIPTOR.message_types_by_name['ListFeatureGroupResponse']
_CREATEFEATUREGROUPREQUEST = DESCRIPTOR.message_types_by_name['CreateFeatureGroupRequest']
_CREATEFEATUREGROUPRESPONSE = DESCRIPTOR.message_types_by_name['CreateFeatureGroupResponse']
_UPDATEFEATUREGROUPREQUEST = DESCRIPTOR.message_types_by_name['UpdateFeatureGroupRequest']
_UPDATEFEATUREGROUPRESPONSE = DESCRIPTOR.message_types_by_name['UpdateFeatureGroupResponse']
_GETFEATUREGROUPREQUEST = DESCRIPTOR.message_types_by_name['GetFeatureGroupRequest']
_GETFEATUREGROUPRESPONSE = DESCRIPTOR.message_types_by_name['GetFeatureGroupResponse']
_DELETEFEATUREGROUPREQUEST = DESCRIPTOR.message_types_by_name['DeleteFeatureGroupRequest']
_DELETEFEATUREGROUPRESPONSE = DESCRIPTOR.message_types_by_name['DeleteFeatureGroupResponse']
_PAUSEFEATUREGROUPRESPONSE = DESCRIPTOR.message_types_by_name['PauseFeatureGroupResponse']
_PAUSEFEATUREGROUPREQUEST = DESCRIPTOR.message_types_by_name['PauseFeatureGroupRequest']
_RESUMEFEATUREGROUPRESPONSE = DESCRIPTOR.message_types_by_name['ResumeFeatureGroupResponse']
_RESUMEFEATUREGROUPREQUEST = DESCRIPTOR.message_types_by_name['ResumeFeatureGroupRequest']
ListFeatureGroupRequest = _reflection.GeneratedProtocolMessageType('ListFeatureGroupRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTFEATUREGROUPREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.featuregroup.v1.featuregroup_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featuregroup.v1.ListFeatureGroupRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTFEATUREGROUPREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.featuregroup.v1.featuregroup_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featuregroup.v1.ListFeatureGroupRequest)
  })
_sym_db.RegisterMessage(ListFeatureGroupRequest)
_sym_db.RegisterMessage(ListFeatureGroupRequest.LabelsEntry)

ListFeatureGroupResponse = _reflection.GeneratedProtocolMessageType('ListFeatureGroupResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTFEATUREGROUPRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.featuregroup.v1.featuregroup_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featuregroup.v1.ListFeatureGroupResponse)
  })
_sym_db.RegisterMessage(ListFeatureGroupResponse)

CreateFeatureGroupRequest = _reflection.GeneratedProtocolMessageType('CreateFeatureGroupRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEFEATUREGROUPREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.featuregroup.v1.featuregroup_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featuregroup.v1.CreateFeatureGroupRequest)
  })
_sym_db.RegisterMessage(CreateFeatureGroupRequest)

CreateFeatureGroupResponse = _reflection.GeneratedProtocolMessageType('CreateFeatureGroupResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEFEATUREGROUPRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.featuregroup.v1.featuregroup_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featuregroup.v1.CreateFeatureGroupResponse)
  })
_sym_db.RegisterMessage(CreateFeatureGroupResponse)

UpdateFeatureGroupRequest = _reflection.GeneratedProtocolMessageType('UpdateFeatureGroupRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEFEATUREGROUPREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.featuregroup.v1.featuregroup_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featuregroup.v1.UpdateFeatureGroupRequest)
  })
_sym_db.RegisterMessage(UpdateFeatureGroupRequest)

UpdateFeatureGroupResponse = _reflection.GeneratedProtocolMessageType('UpdateFeatureGroupResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEFEATUREGROUPRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.featuregroup.v1.featuregroup_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featuregroup.v1.UpdateFeatureGroupResponse)
  })
_sym_db.RegisterMessage(UpdateFeatureGroupResponse)

GetFeatureGroupRequest = _reflection.GeneratedProtocolMessageType('GetFeatureGroupRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETFEATUREGROUPREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.featuregroup.v1.featuregroup_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featuregroup.v1.GetFeatureGroupRequest)
  })
_sym_db.RegisterMessage(GetFeatureGroupRequest)

GetFeatureGroupResponse = _reflection.GeneratedProtocolMessageType('GetFeatureGroupResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETFEATUREGROUPRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.featuregroup.v1.featuregroup_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featuregroup.v1.GetFeatureGroupResponse)
  })
_sym_db.RegisterMessage(GetFeatureGroupResponse)

DeleteFeatureGroupRequest = _reflection.GeneratedProtocolMessageType('DeleteFeatureGroupRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEFEATUREGROUPREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.featuregroup.v1.featuregroup_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featuregroup.v1.DeleteFeatureGroupRequest)
  })
_sym_db.RegisterMessage(DeleteFeatureGroupRequest)

DeleteFeatureGroupResponse = _reflection.GeneratedProtocolMessageType('DeleteFeatureGroupResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEFEATUREGROUPRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.featuregroup.v1.featuregroup_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featuregroup.v1.DeleteFeatureGroupResponse)
  })
_sym_db.RegisterMessage(DeleteFeatureGroupResponse)

PauseFeatureGroupResponse = _reflection.GeneratedProtocolMessageType('PauseFeatureGroupResponse', (_message.Message,), {
  'DESCRIPTOR' : _PAUSEFEATUREGROUPRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.featuregroup.v1.featuregroup_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featuregroup.v1.PauseFeatureGroupResponse)
  })
_sym_db.RegisterMessage(PauseFeatureGroupResponse)

PauseFeatureGroupRequest = _reflection.GeneratedProtocolMessageType('PauseFeatureGroupRequest', (_message.Message,), {
  'DESCRIPTOR' : _PAUSEFEATUREGROUPREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.featuregroup.v1.featuregroup_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featuregroup.v1.PauseFeatureGroupRequest)
  })
_sym_db.RegisterMessage(PauseFeatureGroupRequest)

ResumeFeatureGroupResponse = _reflection.GeneratedProtocolMessageType('ResumeFeatureGroupResponse', (_message.Message,), {
  'DESCRIPTOR' : _RESUMEFEATUREGROUPRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.featuregroup.v1.featuregroup_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featuregroup.v1.ResumeFeatureGroupResponse)
  })
_sym_db.RegisterMessage(ResumeFeatureGroupResponse)

ResumeFeatureGroupRequest = _reflection.GeneratedProtocolMessageType('ResumeFeatureGroupRequest', (_message.Message,), {
  'DESCRIPTOR' : _RESUMEFEATUREGROUPREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.featuregroup.v1.featuregroup_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featuregroup.v1.ResumeFeatureGroupRequest)
  })
_sym_db.RegisterMessage(ResumeFeatureGroupRequest)

_FEATUREGROUPSERVICE = DESCRIPTOR.services_by_name['FeatureGroupService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z6github.com/metaprov/modelaapi/services/featuregroup/v1'
  _LISTFEATUREGROUPREQUEST_LABELSENTRY._options = None
  _LISTFEATUREGROUPREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _FEATUREGROUPSERVICE.methods_by_name['ListFeatureGroups']._options = None
  _FEATUREGROUPSERVICE.methods_by_name['ListFeatureGroups']._serialized_options = b'\202\323\344\223\002\037\022\035/v1/featuregroups/{namespace}'
  _FEATUREGROUPSERVICE.methods_by_name['CreateFeatureGroup']._options = None
  _FEATUREGROUPSERVICE.methods_by_name['CreateFeatureGroup']._serialized_options = b'\202\323\344\223\002\026\"\021/v1/featuregroups:\001*'
  _FEATUREGROUPSERVICE.methods_by_name['GetFeatureGroup']._options = None
  _FEATUREGROUPSERVICE.methods_by_name['GetFeatureGroup']._serialized_options = b'\202\323\344\223\002&\022$/v1/featuregroups/{namespace}/{name}'
  _FEATUREGROUPSERVICE.methods_by_name['UpdateFeatureGroup']._options = None
  _FEATUREGROUPSERVICE.methods_by_name['UpdateFeatureGroup']._serialized_options = b'\202\323\344\223\002U\032P/v1/featuregroups/{featuregroup.metadata.namespace}/{featuregroup.metadata.name}:\001*'
  _FEATUREGROUPSERVICE.methods_by_name['DeleteFeatureGroup']._options = None
  _FEATUREGROUPSERVICE.methods_by_name['DeleteFeatureGroup']._serialized_options = b'\202\323\344\223\002&*$/v1/featuregroups/{namespace}/{name}'
  _FEATUREGROUPSERVICE.methods_by_name['PauseFeatureGroup']._options = None
  _FEATUREGROUPSERVICE.methods_by_name['PauseFeatureGroup']._serialized_options = b'\202\323\344\223\002,\"*/v1/featuregroups/{namespace}/{name}:pause'
  _FEATUREGROUPSERVICE.methods_by_name['ResumeFeatureGroup']._options = None
  _FEATUREGROUPSERVICE.methods_by_name['ResumeFeatureGroup']._serialized_options = b'\202\323\344\223\002,\"*/v1/featuregroups/{namespace}/{name}:pause'
  _LISTFEATUREGROUPREQUEST._serialized_start=268
  _LISTFEATUREGROUPREQUEST._serialized_end=525
  _LISTFEATUREGROUPREQUEST_LABELSENTRY._serialized_start=480
  _LISTFEATUREGROUPREQUEST_LABELSENTRY._serialized_end=525
  _LISTFEATUREGROUPRESPONSE._serialized_start=528
  _LISTFEATUREGROUPRESPONSE._serialized_end=674
  _CREATEFEATUREGROUPREQUEST._serialized_start=676
  _CREATEFEATUREGROUPREQUEST._serialized_end=793
  _CREATEFEATUREGROUPRESPONSE._serialized_start=795
  _CREATEFEATUREGROUPRESPONSE._serialized_end=823
  _UPDATEFEATUREGROUPREQUEST._serialized_start=826
  _UPDATEFEATUREGROUPREQUEST._serialized_end=991
  _UPDATEFEATUREGROUPRESPONSE._serialized_start=993
  _UPDATEFEATUREGROUPRESPONSE._serialized_end=1021
  _GETFEATUREGROUPREQUEST._serialized_start=1023
  _GETFEATUREGROUPREQUEST._serialized_end=1080
  _GETFEATUREGROUPRESPONSE._serialized_start=1083
  _GETFEATUREGROUPRESPONSE._serialized_end=1212
  _DELETEFEATUREGROUPREQUEST._serialized_start=1214
  _DELETEFEATUREGROUPREQUEST._serialized_end=1274
  _DELETEFEATUREGROUPRESPONSE._serialized_start=1276
  _DELETEFEATUREGROUPRESPONSE._serialized_end=1304
  _PAUSEFEATUREGROUPRESPONSE._serialized_start=1306
  _PAUSEFEATUREGROUPRESPONSE._serialized_end=1333
  _PAUSEFEATUREGROUPREQUEST._serialized_start=1335
  _PAUSEFEATUREGROUPREQUEST._serialized_end=1394
  _RESUMEFEATUREGROUPRESPONSE._serialized_start=1396
  _RESUMEFEATUREGROUPRESPONSE._serialized_end=1424
  _RESUMEFEATUREGROUPREQUEST._serialized_start=1426
  _RESUMEFEATUREGROUPREQUEST._serialized_end=1486
  _FEATUREGROUPSERVICE._serialized_start=1489
  _FEATUREGROUPSERVICE._serialized_end=3181
# @@protoc_insertion_point(module_scope)
