# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from github.com.metaprov.modelaapi.services.modelclass.v1 import modelclass_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclass_dot_v1_dot_modelclass__pb2


class ModelClassServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListModelClasses = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.study.v1.ModelClassService/ListModelClasses',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclass_dot_v1_dot_modelclass__pb2.ListModelClassRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclass_dot_v1_dot_modelclass__pb2.ListModelClassResponse.FromString,
                )
        self.CreateModelClass = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.study.v1.ModelClassService/CreateModelClass',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclass_dot_v1_dot_modelclass__pb2.CreateModelClassRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclass_dot_v1_dot_modelclass__pb2.CreateModelClassResponse.FromString,
                )
        self.GetModelClass = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.study.v1.ModelClassService/GetModelClass',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclass_dot_v1_dot_modelclass__pb2.GetModelClassRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclass_dot_v1_dot_modelclass__pb2.GetModelClassResponse.FromString,
                )
        self.UpdateModelClass = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.study.v1.ModelClassService/UpdateModelClass',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclass_dot_v1_dot_modelclass__pb2.UpdateModelClassRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclass_dot_v1_dot_modelclass__pb2.UpdateModelClassResponse.FromString,
                )
        self.DeleteModelClass = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.study.v1.ModelClassService/DeleteModelClass',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclass_dot_v1_dot_modelclass__pb2.DeleteModelClassRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclass_dot_v1_dot_modelclass__pb2.DeleteModelClassResponse.FromString,
                )
        self.CreateModelClassProfile = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.study.v1.ModelClassService/CreateModelClassProfile',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclass_dot_v1_dot_modelclass__pb2.CreateModelClassProfileRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclass_dot_v1_dot_modelclass__pb2.CreateModelClassProfileResponse.FromString,
                )


class ModelClassServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ListModelClasses(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateModelClass(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetModelClass(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateModelClass(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteModelClass(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateModelClassProfile(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ModelClassServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListModelClasses': grpc.unary_unary_rpc_method_handler(
                    servicer.ListModelClasses,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclass_dot_v1_dot_modelclass__pb2.ListModelClassRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclass_dot_v1_dot_modelclass__pb2.ListModelClassResponse.SerializeToString,
            ),
            'CreateModelClass': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateModelClass,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclass_dot_v1_dot_modelclass__pb2.CreateModelClassRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclass_dot_v1_dot_modelclass__pb2.CreateModelClassResponse.SerializeToString,
            ),
            'GetModelClass': grpc.unary_unary_rpc_method_handler(
                    servicer.GetModelClass,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclass_dot_v1_dot_modelclass__pb2.GetModelClassRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclass_dot_v1_dot_modelclass__pb2.GetModelClassResponse.SerializeToString,
            ),
            'UpdateModelClass': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateModelClass,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclass_dot_v1_dot_modelclass__pb2.UpdateModelClassRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclass_dot_v1_dot_modelclass__pb2.UpdateModelClassResponse.SerializeToString,
            ),
            'DeleteModelClass': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteModelClass,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclass_dot_v1_dot_modelclass__pb2.DeleteModelClassRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclass_dot_v1_dot_modelclass__pb2.DeleteModelClassResponse.SerializeToString,
            ),
            'CreateModelClassProfile': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateModelClassProfile,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclass_dot_v1_dot_modelclass__pb2.CreateModelClassProfileRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclass_dot_v1_dot_modelclass__pb2.CreateModelClassProfileResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'github.com.metaprov.modelaapi.services.study.v1.ModelClassService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class ModelClassService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ListModelClasses(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.study.v1.ModelClassService/ListModelClasses',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclass_dot_v1_dot_modelclass__pb2.ListModelClassRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclass_dot_v1_dot_modelclass__pb2.ListModelClassResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateModelClass(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.study.v1.ModelClassService/CreateModelClass',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclass_dot_v1_dot_modelclass__pb2.CreateModelClassRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclass_dot_v1_dot_modelclass__pb2.CreateModelClassResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetModelClass(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.study.v1.ModelClassService/GetModelClass',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclass_dot_v1_dot_modelclass__pb2.GetModelClassRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclass_dot_v1_dot_modelclass__pb2.GetModelClassResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateModelClass(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.study.v1.ModelClassService/UpdateModelClass',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclass_dot_v1_dot_modelclass__pb2.UpdateModelClassRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclass_dot_v1_dot_modelclass__pb2.UpdateModelClassResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteModelClass(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.study.v1.ModelClassService/DeleteModelClass',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclass_dot_v1_dot_modelclass__pb2.DeleteModelClassRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclass_dot_v1_dot_modelclass__pb2.DeleteModelClassResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateModelClassProfile(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.study.v1.ModelClassService/CreateModelClassProfile',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclass_dot_v1_dot_modelclass__pb2.CreateModelClassProfileRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelclass_dot_v1_dot_modelclass__pb2.CreateModelClassProfileResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
