# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from github.com.metaprov.modelaapi.services.featuregroup.v1 import featuregroup_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featuregroup_dot_v1_dot_featuregroup__pb2


class FeatureGroupServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListFeatureGroups = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.featuregroup.v1.FeatureGroupService/ListFeatureGroups',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featuregroup_dot_v1_dot_featuregroup__pb2.ListFeatureGroupRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featuregroup_dot_v1_dot_featuregroup__pb2.ListFeatureGroupResponse.FromString,
                )
        self.CreateFeatureGroup = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.featuregroup.v1.FeatureGroupService/CreateFeatureGroup',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featuregroup_dot_v1_dot_featuregroup__pb2.CreateFeatureGroupRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featuregroup_dot_v1_dot_featuregroup__pb2.CreateFeatureGroupResponse.FromString,
                )
        self.GetFeatureGroup = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.featuregroup.v1.FeatureGroupService/GetFeatureGroup',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featuregroup_dot_v1_dot_featuregroup__pb2.GetFeatureGroupRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featuregroup_dot_v1_dot_featuregroup__pb2.GetFeatureGroupResponse.FromString,
                )
        self.UpdateFeatureGroup = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.featuregroup.v1.FeatureGroupService/UpdateFeatureGroup',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featuregroup_dot_v1_dot_featuregroup__pb2.UpdateFeatureGroupRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featuregroup_dot_v1_dot_featuregroup__pb2.UpdateFeatureGroupResponse.FromString,
                )
        self.DeleteFeatureGroup = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.featuregroup.v1.FeatureGroupService/DeleteFeatureGroup',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featuregroup_dot_v1_dot_featuregroup__pb2.DeleteFeatureGroupRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featuregroup_dot_v1_dot_featuregroup__pb2.DeleteFeatureGroupResponse.FromString,
                )
        self.PauseFeatureGroup = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.featuregroup.v1.FeatureGroupService/PauseFeatureGroup',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featuregroup_dot_v1_dot_featuregroup__pb2.PauseFeatureGroupRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featuregroup_dot_v1_dot_featuregroup__pb2.PauseFeatureGroupResponse.FromString,
                )
        self.ResumeFeatureGroup = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.featuregroup.v1.FeatureGroupService/ResumeFeatureGroup',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featuregroup_dot_v1_dot_featuregroup__pb2.ResumeFeatureGroupRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featuregroup_dot_v1_dot_featuregroup__pb2.ResumeFeatureGroupResponse.FromString,
                )


class FeatureGroupServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ListFeatureGroups(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateFeatureGroup(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetFeatureGroup(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateFeatureGroup(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteFeatureGroup(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PauseFeatureGroup(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ResumeFeatureGroup(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_FeatureGroupServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListFeatureGroups': grpc.unary_unary_rpc_method_handler(
                    servicer.ListFeatureGroups,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featuregroup_dot_v1_dot_featuregroup__pb2.ListFeatureGroupRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featuregroup_dot_v1_dot_featuregroup__pb2.ListFeatureGroupResponse.SerializeToString,
            ),
            'CreateFeatureGroup': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateFeatureGroup,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featuregroup_dot_v1_dot_featuregroup__pb2.CreateFeatureGroupRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featuregroup_dot_v1_dot_featuregroup__pb2.CreateFeatureGroupResponse.SerializeToString,
            ),
            'GetFeatureGroup': grpc.unary_unary_rpc_method_handler(
                    servicer.GetFeatureGroup,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featuregroup_dot_v1_dot_featuregroup__pb2.GetFeatureGroupRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featuregroup_dot_v1_dot_featuregroup__pb2.GetFeatureGroupResponse.SerializeToString,
            ),
            'UpdateFeatureGroup': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateFeatureGroup,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featuregroup_dot_v1_dot_featuregroup__pb2.UpdateFeatureGroupRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featuregroup_dot_v1_dot_featuregroup__pb2.UpdateFeatureGroupResponse.SerializeToString,
            ),
            'DeleteFeatureGroup': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteFeatureGroup,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featuregroup_dot_v1_dot_featuregroup__pb2.DeleteFeatureGroupRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featuregroup_dot_v1_dot_featuregroup__pb2.DeleteFeatureGroupResponse.SerializeToString,
            ),
            'PauseFeatureGroup': grpc.unary_unary_rpc_method_handler(
                    servicer.PauseFeatureGroup,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featuregroup_dot_v1_dot_featuregroup__pb2.PauseFeatureGroupRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featuregroup_dot_v1_dot_featuregroup__pb2.PauseFeatureGroupResponse.SerializeToString,
            ),
            'ResumeFeatureGroup': grpc.unary_unary_rpc_method_handler(
                    servicer.ResumeFeatureGroup,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featuregroup_dot_v1_dot_featuregroup__pb2.ResumeFeatureGroupRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featuregroup_dot_v1_dot_featuregroup__pb2.ResumeFeatureGroupResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'github.com.metaprov.modelaapi.services.featuregroup.v1.FeatureGroupService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class FeatureGroupService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ListFeatureGroups(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.featuregroup.v1.FeatureGroupService/ListFeatureGroups',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featuregroup_dot_v1_dot_featuregroup__pb2.ListFeatureGroupRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featuregroup_dot_v1_dot_featuregroup__pb2.ListFeatureGroupResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateFeatureGroup(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.featuregroup.v1.FeatureGroupService/CreateFeatureGroup',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featuregroup_dot_v1_dot_featuregroup__pb2.CreateFeatureGroupRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featuregroup_dot_v1_dot_featuregroup__pb2.CreateFeatureGroupResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetFeatureGroup(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.featuregroup.v1.FeatureGroupService/GetFeatureGroup',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featuregroup_dot_v1_dot_featuregroup__pb2.GetFeatureGroupRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featuregroup_dot_v1_dot_featuregroup__pb2.GetFeatureGroupResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateFeatureGroup(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.featuregroup.v1.FeatureGroupService/UpdateFeatureGroup',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featuregroup_dot_v1_dot_featuregroup__pb2.UpdateFeatureGroupRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featuregroup_dot_v1_dot_featuregroup__pb2.UpdateFeatureGroupResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteFeatureGroup(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.featuregroup.v1.FeatureGroupService/DeleteFeatureGroup',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featuregroup_dot_v1_dot_featuregroup__pb2.DeleteFeatureGroupRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featuregroup_dot_v1_dot_featuregroup__pb2.DeleteFeatureGroupResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def PauseFeatureGroup(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.featuregroup.v1.FeatureGroupService/PauseFeatureGroup',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featuregroup_dot_v1_dot_featuregroup__pb2.PauseFeatureGroupRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featuregroup_dot_v1_dot_featuregroup__pb2.PauseFeatureGroupResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ResumeFeatureGroup(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.featuregroup.v1.FeatureGroupService/ResumeFeatureGroup',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featuregroup_dot_v1_dot_featuregroup__pb2.ResumeFeatureGroupRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featuregroup_dot_v1_dot_featuregroup__pb2.ResumeFeatureGroupResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
