# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/alert/v1/alert.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2
from github.com.metaprov.modelaapi.services.common.v1 import common_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_common_dot_v1_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n;github.com/metaprov/modelaapi/services/alert/v1/alert.proto\x12/github.com.metaprov.modelaapi.services.alert.v1\x1a google/protobuf/field_mask.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x45github.com/metaprov/modelaapi/pkg/apis/infra/v1alpha1/generated.proto\x1a=github.com/metaprov/modelaapi/services/common/v1/common.proto\"\xee\x01\n\x11ListAlertsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12^\n\x06labels\x18\x02 \x03(\x0b\x32N.github.com.metaprov.modelaapi.services.alert.v1.ListAlertsRequest.LabelsEntry\x12\x11\n\tpage_size\x18\x03 \x01(\x05\x12\x12\n\npage_token\x18\x04 \x01(\t\x12\x10\n\x08order_by\x18\x05 \x01(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x7f\n\x12ListAlertsResponse\x12P\n\x06\x61lerts\x18\x01 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.AlertList\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x0f\n\rAlertResponse\"a\n\x12\x43reateAlertRequest\x12K\n\x05\x61lert\x18\x01 \x01(\x0b\x32<.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Alert\"\x15\n\x13\x43reateAlertResponse\"\x92\x01\n\x12UpdateAlertRequest\x12K\n\x05\x61lert\x18\x01 \x01(\x0b\x32<.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Alert\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\"\x15\n\x13UpdateAlertResponse\"2\n\x0fGetAlertRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"m\n\x10GetAlertResponse\x12K\n\x05\x61lert\x18\x01 \x01(\x0b\x32<.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Alert\x12\x0c\n\x04yaml\x18\x02 \x01(\t\"<\n\x19GetAlertNamespacesRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"q\n\x1aGetAlertNamespacesResponse\x12S\n\nnamespaces\x18\x01 \x03(\x0b\x32?.github.com.metaprov.modelaapi.services.common.v1.NamespaceInfo\"5\n\x12\x44\x65leteAlertRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x15\n\x13\x44\x65leteAlertResponse2\xd6\x07\n\x0c\x41lertService\x12\xb5\x01\n\nListAlerts\x12\x42.github.com.metaprov.modelaapi.services.alert.v1.ListAlertsRequest\x1a\x43.github.com.metaprov.modelaapi.services.alert.v1.ListAlertsResponse\"\x1e\x82\xd3\xe4\x93\x02\x18\x12\x16/v1/alerts/{namespace}\x12\xaf\x01\n\x0b\x43reateAlert\x12\x43.github.com.metaprov.modelaapi.services.alert.v1.CreateAlertRequest\x1a\x44.github.com.metaprov.modelaapi.services.alert.v1.CreateAlertResponse\"\x15\x82\xd3\xe4\x93\x02\x0f\"\n/v1/alerts:\x01*\x12\xb6\x01\n\x08GetAlert\x12@.github.com.metaprov.modelaapi.services.alert.v1.GetAlertRequest\x1a\x41.github.com.metaprov.modelaapi.services.alert.v1.GetAlertResponse\"%\x82\xd3\xe4\x93\x02\x1f\x12\x1d/v1/alerts/{namespace}/{name}\x12\xe0\x01\n\x0bUpdateAlert\x12\x43.github.com.metaprov.modelaapi.services.alert.v1.UpdateAlertRequest\x1a\x44.github.com.metaprov.modelaapi.services.alert.v1.UpdateAlertResponse\"F\x82\xd3\xe4\x93\x02@\x1a;/v1/alerts/{alert.metadata.namespace}/{alert.metadata.name}:\x01*\x12\xbf\x01\n\x0b\x44\x65leteAlert\x12\x43.github.com.metaprov.modelaapi.services.alert.v1.DeleteAlertRequest\x1a\x44.github.com.metaprov.modelaapi.services.alert.v1.DeleteAlertResponse\"%\x82\xd3\xe4\x93\x02\x1f*\x1d/v1/alerts/{namespace}/{name}B1Z/github.com/metaprov/modelaapi/services/alert/v1b\x06proto3')



_LISTALERTSREQUEST = DESCRIPTOR.message_types_by_name['ListAlertsRequest']
_LISTALERTSREQUEST_LABELSENTRY = _LISTALERTSREQUEST.nested_types_by_name['LabelsEntry']
_LISTALERTSRESPONSE = DESCRIPTOR.message_types_by_name['ListAlertsResponse']
_ALERTRESPONSE = DESCRIPTOR.message_types_by_name['AlertResponse']
_CREATEALERTREQUEST = DESCRIPTOR.message_types_by_name['CreateAlertRequest']
_CREATEALERTRESPONSE = DESCRIPTOR.message_types_by_name['CreateAlertResponse']
_UPDATEALERTREQUEST = DESCRIPTOR.message_types_by_name['UpdateAlertRequest']
_UPDATEALERTRESPONSE = DESCRIPTOR.message_types_by_name['UpdateAlertResponse']
_GETALERTREQUEST = DESCRIPTOR.message_types_by_name['GetAlertRequest']
_GETALERTRESPONSE = DESCRIPTOR.message_types_by_name['GetAlertResponse']
_GETALERTNAMESPACESREQUEST = DESCRIPTOR.message_types_by_name['GetAlertNamespacesRequest']
_GETALERTNAMESPACESRESPONSE = DESCRIPTOR.message_types_by_name['GetAlertNamespacesResponse']
_DELETEALERTREQUEST = DESCRIPTOR.message_types_by_name['DeleteAlertRequest']
_DELETEALERTRESPONSE = DESCRIPTOR.message_types_by_name['DeleteAlertResponse']
ListAlertsRequest = _reflection.GeneratedProtocolMessageType('ListAlertsRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTALERTSREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.alert.v1.alert_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.alert.v1.ListAlertsRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTALERTSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.alert.v1.alert_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.alert.v1.ListAlertsRequest)
  })
_sym_db.RegisterMessage(ListAlertsRequest)
_sym_db.RegisterMessage(ListAlertsRequest.LabelsEntry)

ListAlertsResponse = _reflection.GeneratedProtocolMessageType('ListAlertsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTALERTSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.alert.v1.alert_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.alert.v1.ListAlertsResponse)
  })
_sym_db.RegisterMessage(ListAlertsResponse)

AlertResponse = _reflection.GeneratedProtocolMessageType('AlertResponse', (_message.Message,), {
  'DESCRIPTOR' : _ALERTRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.alert.v1.alert_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.alert.v1.AlertResponse)
  })
_sym_db.RegisterMessage(AlertResponse)

CreateAlertRequest = _reflection.GeneratedProtocolMessageType('CreateAlertRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEALERTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.alert.v1.alert_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.alert.v1.CreateAlertRequest)
  })
_sym_db.RegisterMessage(CreateAlertRequest)

CreateAlertResponse = _reflection.GeneratedProtocolMessageType('CreateAlertResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEALERTRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.alert.v1.alert_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.alert.v1.CreateAlertResponse)
  })
_sym_db.RegisterMessage(CreateAlertResponse)

UpdateAlertRequest = _reflection.GeneratedProtocolMessageType('UpdateAlertRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEALERTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.alert.v1.alert_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.alert.v1.UpdateAlertRequest)
  })
_sym_db.RegisterMessage(UpdateAlertRequest)

UpdateAlertResponse = _reflection.GeneratedProtocolMessageType('UpdateAlertResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEALERTRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.alert.v1.alert_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.alert.v1.UpdateAlertResponse)
  })
_sym_db.RegisterMessage(UpdateAlertResponse)

GetAlertRequest = _reflection.GeneratedProtocolMessageType('GetAlertRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETALERTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.alert.v1.alert_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.alert.v1.GetAlertRequest)
  })
_sym_db.RegisterMessage(GetAlertRequest)

GetAlertResponse = _reflection.GeneratedProtocolMessageType('GetAlertResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETALERTRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.alert.v1.alert_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.alert.v1.GetAlertResponse)
  })
_sym_db.RegisterMessage(GetAlertResponse)

GetAlertNamespacesRequest = _reflection.GeneratedProtocolMessageType('GetAlertNamespacesRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETALERTNAMESPACESREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.alert.v1.alert_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.alert.v1.GetAlertNamespacesRequest)
  })
_sym_db.RegisterMessage(GetAlertNamespacesRequest)

GetAlertNamespacesResponse = _reflection.GeneratedProtocolMessageType('GetAlertNamespacesResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETALERTNAMESPACESRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.alert.v1.alert_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.alert.v1.GetAlertNamespacesResponse)
  })
_sym_db.RegisterMessage(GetAlertNamespacesResponse)

DeleteAlertRequest = _reflection.GeneratedProtocolMessageType('DeleteAlertRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEALERTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.alert.v1.alert_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.alert.v1.DeleteAlertRequest)
  })
_sym_db.RegisterMessage(DeleteAlertRequest)

DeleteAlertResponse = _reflection.GeneratedProtocolMessageType('DeleteAlertResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEALERTRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.alert.v1.alert_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.alert.v1.DeleteAlertResponse)
  })
_sym_db.RegisterMessage(DeleteAlertResponse)

_ALERTSERVICE = DESCRIPTOR.services_by_name['AlertService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z/github.com/metaprov/modelaapi/services/alert/v1'
  _LISTALERTSREQUEST_LABELSENTRY._options = None
  _LISTALERTSREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _ALERTSERVICE.methods_by_name['ListAlerts']._options = None
  _ALERTSERVICE.methods_by_name['ListAlerts']._serialized_options = b'\202\323\344\223\002\030\022\026/v1/alerts/{namespace}'
  _ALERTSERVICE.methods_by_name['CreateAlert']._options = None
  _ALERTSERVICE.methods_by_name['CreateAlert']._serialized_options = b'\202\323\344\223\002\017\"\n/v1/alerts:\001*'
  _ALERTSERVICE.methods_by_name['GetAlert']._options = None
  _ALERTSERVICE.methods_by_name['GetAlert']._serialized_options = b'\202\323\344\223\002\037\022\035/v1/alerts/{namespace}/{name}'
  _ALERTSERVICE.methods_by_name['UpdateAlert']._options = None
  _ALERTSERVICE.methods_by_name['UpdateAlert']._serialized_options = b'\202\323\344\223\002@\032;/v1/alerts/{alert.metadata.namespace}/{alert.metadata.name}:\001*'
  _ALERTSERVICE.methods_by_name['DeleteAlert']._options = None
  _ALERTSERVICE.methods_by_name['DeleteAlert']._serialized_options = b'\202\323\344\223\002\037*\035/v1/alerts/{namespace}/{name}'
  _LISTALERTSREQUEST._serialized_start=311
  _LISTALERTSREQUEST._serialized_end=549
  _LISTALERTSREQUEST_LABELSENTRY._serialized_start=504
  _LISTALERTSREQUEST_LABELSENTRY._serialized_end=549
  _LISTALERTSRESPONSE._serialized_start=551
  _LISTALERTSRESPONSE._serialized_end=678
  _ALERTRESPONSE._serialized_start=680
  _ALERTRESPONSE._serialized_end=695
  _CREATEALERTREQUEST._serialized_start=697
  _CREATEALERTREQUEST._serialized_end=794
  _CREATEALERTRESPONSE._serialized_start=796
  _CREATEALERTRESPONSE._serialized_end=817
  _UPDATEALERTREQUEST._serialized_start=820
  _UPDATEALERTREQUEST._serialized_end=966
  _UPDATEALERTRESPONSE._serialized_start=968
  _UPDATEALERTRESPONSE._serialized_end=989
  _GETALERTREQUEST._serialized_start=991
  _GETALERTREQUEST._serialized_end=1041
  _GETALERTRESPONSE._serialized_start=1043
  _GETALERTRESPONSE._serialized_end=1152
  _GETALERTNAMESPACESREQUEST._serialized_start=1154
  _GETALERTNAMESPACESREQUEST._serialized_end=1214
  _GETALERTNAMESPACESRESPONSE._serialized_start=1216
  _GETALERTNAMESPACESRESPONSE._serialized_end=1329
  _DELETEALERTREQUEST._serialized_start=1331
  _DELETEALERTREQUEST._serialized_end=1384
  _DELETEALERTRESPONSE._serialized_start=1386
  _DELETEALERTRESPONSE._serialized_end=1407
  _ALERTSERVICE._serialized_start=1410
  _ALERTSERVICE._serialized_end=2392
# @@protoc_insertion_point(module_scope)
