# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/lab/v1/lab.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2
from github.com.metaprov.modelaapi.services.common.v1 import common_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_common_dot_v1_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n7github.com/metaprov/modelaapi/services/lab/v1/lab.proto\x12-github.com.metaprov.modelaapi.services.lab.v1\x1a google/protobuf/field_mask.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x45github.com/metaprov/modelaapi/pkg/apis/infra/v1alpha1/generated.proto\x1a=github.com/metaprov/modelaapi/services/common/v1/common.proto\"\xe8\x01\n\x0fListLabsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12Z\n\x06labels\x18\x02 \x03(\x0b\x32J.github.com.metaprov.modelaapi.services.lab.v1.ListLabsRequest.LabelsEntry\x12\x11\n\tpage_size\x18\x03 \x01(\x05\x12\x12\n\npage_token\x18\x04 \x01(\t\x12\x10\n\x08order_by\x18\x05 \x01(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"y\n\x10ListLabsResponse\x12L\n\x04labs\x18\x01 \x01(\x0b\x32>.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.LabList\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\r\n\x0bLabResponse\"[\n\x10\x43reateLabRequest\x12G\n\x03lab\x18\x01 \x01(\x0b\x32:.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Lab\"\x13\n\x11\x43reateLabResponse\"\x8b\x01\n\x10UpdateLabRequest\x12G\n\x03lab\x18\x01 \x01(\x0b\x32:.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Lab\x12.\n\nfield_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\"\x13\n\x11UpdateLabResponse\"0\n\rGetLabRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"g\n\x0eGetLabResponse\x12G\n\x03lab\x18\x01 \x01(\x0b\x32:.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Lab\x12\x0c\n\x04yaml\x18\x02 \x01(\t\":\n\x17GetLabNamespacesRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"o\n\x18GetLabNamespacesResponse\x12S\n\nnamespaces\x18\x01 \x03(\x0b\x32?.github.com.metaprov.modelaapi.services.common.v1.NamespaceInfo\"3\n\x10\x44\x65leteLabRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x13\n\x11\x44\x65leteLabResponse2\x94\x07\n\nLabService\x12\xa9\x01\n\x08ListLabs\x12>.github.com.metaprov.modelaapi.services.lab.v1.ListLabsRequest\x1a?.github.com.metaprov.modelaapi.services.lab.v1.ListLabsResponse\"\x1c\x82\xd3\xe4\x93\x02\x16\x12\x14/v1/labs/{namespace}\x12\xa3\x01\n\tCreateLab\x12?.github.com.metaprov.modelaapi.services.lab.v1.CreateLabRequest\x1a@.github.com.metaprov.modelaapi.services.lab.v1.CreateLabResponse\"\x13\x82\xd3\xe4\x93\x02\r\"\x08/v1/labs:\x01*\x12\xaa\x01\n\x06GetLab\x12<.github.com.metaprov.modelaapi.services.lab.v1.GetLabRequest\x1a=.github.com.metaprov.modelaapi.services.lab.v1.GetLabResponse\"#\x82\xd3\xe4\x93\x02\x1d\x12\x1b/v1/labs/{namespace}/{name}\x12\xd0\x01\n\tUpdateLab\x12?.github.com.metaprov.modelaapi.services.lab.v1.UpdateLabRequest\x1a@.github.com.metaprov.modelaapi.services.lab.v1.UpdateLabResponse\"@\x82\xd3\xe4\x93\x02:\x1a\x35/v1/labs/{lab.metadata.namespace}/{lab.metadata.name}:\x01*\x12\xb3\x01\n\tDeleteLab\x12?.github.com.metaprov.modelaapi.services.lab.v1.DeleteLabRequest\x1a@.github.com.metaprov.modelaapi.services.lab.v1.DeleteLabResponse\"#\x82\xd3\xe4\x93\x02\x1d*\x1b/v1/labs/{namespace}/{name}B/Z-github.com/metaprov/modelaapi/services/lab/v1b\x06proto3')



_LISTLABSREQUEST = DESCRIPTOR.message_types_by_name['ListLabsRequest']
_LISTLABSREQUEST_LABELSENTRY = _LISTLABSREQUEST.nested_types_by_name['LabelsEntry']
_LISTLABSRESPONSE = DESCRIPTOR.message_types_by_name['ListLabsResponse']
_LABRESPONSE = DESCRIPTOR.message_types_by_name['LabResponse']
_CREATELABREQUEST = DESCRIPTOR.message_types_by_name['CreateLabRequest']
_CREATELABRESPONSE = DESCRIPTOR.message_types_by_name['CreateLabResponse']
_UPDATELABREQUEST = DESCRIPTOR.message_types_by_name['UpdateLabRequest']
_UPDATELABRESPONSE = DESCRIPTOR.message_types_by_name['UpdateLabResponse']
_GETLABREQUEST = DESCRIPTOR.message_types_by_name['GetLabRequest']
_GETLABRESPONSE = DESCRIPTOR.message_types_by_name['GetLabResponse']
_GETLABNAMESPACESREQUEST = DESCRIPTOR.message_types_by_name['GetLabNamespacesRequest']
_GETLABNAMESPACESRESPONSE = DESCRIPTOR.message_types_by_name['GetLabNamespacesResponse']
_DELETELABREQUEST = DESCRIPTOR.message_types_by_name['DeleteLabRequest']
_DELETELABRESPONSE = DESCRIPTOR.message_types_by_name['DeleteLabResponse']
ListLabsRequest = _reflection.GeneratedProtocolMessageType('ListLabsRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTLABSREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.lab.v1.lab_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.lab.v1.ListLabsRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTLABSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.lab.v1.lab_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.lab.v1.ListLabsRequest)
  })
_sym_db.RegisterMessage(ListLabsRequest)
_sym_db.RegisterMessage(ListLabsRequest.LabelsEntry)

ListLabsResponse = _reflection.GeneratedProtocolMessageType('ListLabsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTLABSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.lab.v1.lab_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.lab.v1.ListLabsResponse)
  })
_sym_db.RegisterMessage(ListLabsResponse)

LabResponse = _reflection.GeneratedProtocolMessageType('LabResponse', (_message.Message,), {
  'DESCRIPTOR' : _LABRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.lab.v1.lab_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.lab.v1.LabResponse)
  })
_sym_db.RegisterMessage(LabResponse)

CreateLabRequest = _reflection.GeneratedProtocolMessageType('CreateLabRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATELABREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.lab.v1.lab_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.lab.v1.CreateLabRequest)
  })
_sym_db.RegisterMessage(CreateLabRequest)

CreateLabResponse = _reflection.GeneratedProtocolMessageType('CreateLabResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATELABRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.lab.v1.lab_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.lab.v1.CreateLabResponse)
  })
_sym_db.RegisterMessage(CreateLabResponse)

UpdateLabRequest = _reflection.GeneratedProtocolMessageType('UpdateLabRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATELABREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.lab.v1.lab_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.lab.v1.UpdateLabRequest)
  })
_sym_db.RegisterMessage(UpdateLabRequest)

UpdateLabResponse = _reflection.GeneratedProtocolMessageType('UpdateLabResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATELABRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.lab.v1.lab_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.lab.v1.UpdateLabResponse)
  })
_sym_db.RegisterMessage(UpdateLabResponse)

GetLabRequest = _reflection.GeneratedProtocolMessageType('GetLabRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETLABREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.lab.v1.lab_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.lab.v1.GetLabRequest)
  })
_sym_db.RegisterMessage(GetLabRequest)

GetLabResponse = _reflection.GeneratedProtocolMessageType('GetLabResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETLABRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.lab.v1.lab_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.lab.v1.GetLabResponse)
  })
_sym_db.RegisterMessage(GetLabResponse)

GetLabNamespacesRequest = _reflection.GeneratedProtocolMessageType('GetLabNamespacesRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETLABNAMESPACESREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.lab.v1.lab_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.lab.v1.GetLabNamespacesRequest)
  })
_sym_db.RegisterMessage(GetLabNamespacesRequest)

GetLabNamespacesResponse = _reflection.GeneratedProtocolMessageType('GetLabNamespacesResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETLABNAMESPACESRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.lab.v1.lab_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.lab.v1.GetLabNamespacesResponse)
  })
_sym_db.RegisterMessage(GetLabNamespacesResponse)

DeleteLabRequest = _reflection.GeneratedProtocolMessageType('DeleteLabRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETELABREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.lab.v1.lab_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.lab.v1.DeleteLabRequest)
  })
_sym_db.RegisterMessage(DeleteLabRequest)

DeleteLabResponse = _reflection.GeneratedProtocolMessageType('DeleteLabResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETELABRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.lab.v1.lab_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.lab.v1.DeleteLabResponse)
  })
_sym_db.RegisterMessage(DeleteLabResponse)

_LABSERVICE = DESCRIPTOR.services_by_name['LabService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z-github.com/metaprov/modelaapi/services/lab/v1'
  _LISTLABSREQUEST_LABELSENTRY._options = None
  _LISTLABSREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _LABSERVICE.methods_by_name['ListLabs']._options = None
  _LABSERVICE.methods_by_name['ListLabs']._serialized_options = b'\202\323\344\223\002\026\022\024/v1/labs/{namespace}'
  _LABSERVICE.methods_by_name['CreateLab']._options = None
  _LABSERVICE.methods_by_name['CreateLab']._serialized_options = b'\202\323\344\223\002\r\"\010/v1/labs:\001*'
  _LABSERVICE.methods_by_name['GetLab']._options = None
  _LABSERVICE.methods_by_name['GetLab']._serialized_options = b'\202\323\344\223\002\035\022\033/v1/labs/{namespace}/{name}'
  _LABSERVICE.methods_by_name['UpdateLab']._options = None
  _LABSERVICE.methods_by_name['UpdateLab']._serialized_options = b'\202\323\344\223\002:\0325/v1/labs/{lab.metadata.namespace}/{lab.metadata.name}:\001*'
  _LABSERVICE.methods_by_name['DeleteLab']._options = None
  _LABSERVICE.methods_by_name['DeleteLab']._serialized_options = b'\202\323\344\223\002\035*\033/v1/labs/{namespace}/{name}'
  _LISTLABSREQUEST._serialized_start=305
  _LISTLABSREQUEST._serialized_end=537
  _LISTLABSREQUEST_LABELSENTRY._serialized_start=492
  _LISTLABSREQUEST_LABELSENTRY._serialized_end=537
  _LISTLABSRESPONSE._serialized_start=539
  _LISTLABSRESPONSE._serialized_end=660
  _LABRESPONSE._serialized_start=662
  _LABRESPONSE._serialized_end=675
  _CREATELABREQUEST._serialized_start=677
  _CREATELABREQUEST._serialized_end=768
  _CREATELABRESPONSE._serialized_start=770
  _CREATELABRESPONSE._serialized_end=789
  _UPDATELABREQUEST._serialized_start=792
  _UPDATELABREQUEST._serialized_end=931
  _UPDATELABRESPONSE._serialized_start=933
  _UPDATELABRESPONSE._serialized_end=952
  _GETLABREQUEST._serialized_start=954
  _GETLABREQUEST._serialized_end=1002
  _GETLABRESPONSE._serialized_start=1004
  _GETLABRESPONSE._serialized_end=1107
  _GETLABNAMESPACESREQUEST._serialized_start=1109
  _GETLABNAMESPACESREQUEST._serialized_end=1167
  _GETLABNAMESPACESRESPONSE._serialized_start=1169
  _GETLABNAMESPACESRESPONSE._serialized_end=1280
  _DELETELABREQUEST._serialized_start=1282
  _DELETELABREQUEST._serialized_end=1333
  _DELETELABRESPONSE._serialized_start=1335
  _DELETELABRESPONSE._serialized_end=1354
  _LABSERVICE._serialized_start=1357
  _LABSERVICE._serialized_end=2273
# @@protoc_insertion_point(module_scope)
