# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: k8s.io/apimachinery/pkg/api/resource/generated.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n4k8s.io/apimachinery/pkg/api/resource/generated.proto\x12$k8s.io.apimachinery.pkg.api.resource\"\x1a\n\x08Quantity\x12\x0e\n\x06string\x18\x01 \x01(\t\"\x1f\n\rQuantityValue\x12\x0e\n\x06string\x18\x01 \x01(\tB&Z$k8s.io/apimachinery/pkg/api/resource')



_QUANTITY = DESCRIPTOR.message_types_by_name['Quantity']
_QUANTITYVALUE = DESCRIPTOR.message_types_by_name['QuantityValue']
Quantity = _reflection.GeneratedProtocolMessageType('Quantity', (_message.Message,), {
  'DESCRIPTOR' : _QUANTITY,
  '__module__' : 'k8s.io.apimachinery.pkg.api.resource.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.apimachinery.pkg.api.resource.Quantity)
  })
_sym_db.RegisterMessage(Quantity)

QuantityValue = _reflection.GeneratedProtocolMessageType('QuantityValue', (_message.Message,), {
  'DESCRIPTOR' : _QUANTITYVALUE,
  '__module__' : 'k8s.io.apimachinery.pkg.api.resource.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.apimachinery.pkg.api.resource.QuantityValue)
  })
_sym_db.RegisterMessage(QuantityValue)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z$k8s.io/apimachinery/pkg/api/resource'
  _QUANTITY._serialized_start=94
  _QUANTITY._serialized_end=120
  _QUANTITYVALUE._serialized_start=122
  _QUANTITYVALUE._serialized_end=153
# @@protoc_insertion_point(module_scope)
